// used in src/Languages.cpp, encoding=UTF8
const char* langNames[] = {
	"Հայոց լեզու",
	"简体字",
	"繁體字",
	"Česky",
	"Dansk",
	"Deutsch",
	"English",
	"Español",
	"Euskara",
	"Français",
	"Ελληνικά",
	"Italiano",
	"日本語 ",
	"한국어",
	"Magyar",
	"Македонски",
	"Nederlands",
	"Norsk",
	"Polski",
	"Português",
	"Português (Brasil)",
	"Pyccкий",
	"Slovenčina",
	"Slovenščina",
	"Srpski",
	"Svenska",
	"Украї́нська",
	"tiếng Việt"
};

const wxLanguage langIds[] = {
	wxLANGUAGE_ARMENIAN,
	wxLANGUAGE_CHINESE_SIMPLIFIED,
	wxLANGUAGE_CHINESE_TRADITIONAL,
	wxLANGUAGE_CZECH,
	wxLANGUAGE_DANISH,
	wxLANGUAGE_GERMAN,
	wxLANGUAGE_ENGLISH,
	wxLANGUAGE_SPANISH,
	wxLANGUAGE_BASQUE,
	wxLANGUAGE_FRENCH,
	wxLANGUAGE_GREEK,
	wxLANGUAGE_ITALIAN,
	wxLANGUAGE_JAPANESE,
	wxLANGUAGE_KOREAN,
	wxLANGUAGE_HUNGARIAN,
	wxLANGUAGE_MACEDONIAN,
	wxLANGUAGE_DUTCH,
	wxLANGUAGE_NORWEGIAN_BOKMAL,
	wxLANGUAGE_POLISH,
	wxLANGUAGE_PORTUGUESE,
	wxLANGUAGE_PORTUGUESE_BRAZILIAN,
	wxLANGUAGE_RUSSIAN,
	wxLANGUAGE_SLOVAK,
	wxLANGUAGE_SLOVENIAN,
	wxLANGUAGE_SERBIAN,
	wxLANGUAGE_SWEDISH,
	wxLANGUAGE_UKRAINIAN,
	wxLANGUAGE_VIETNAMESE
};

#include "bitmaps/armenia.png.h"
#include "bitmaps/china.png.h"
#include "bitmaps/czech.png.h"
#include "bitmaps/denmark.png.h"
#include "bitmaps/germany.png.h"
#include "bitmaps/united_kingdom.png.h"
#include "bitmaps/spain.png.h"
#include "bitmaps/basque_country.png.h"
#include "bitmaps/france.png.h"
#include "bitmaps/greece.png.h"
#include "bitmaps/italy.png.h"
#include "bitmaps/japan.png.h"
#include "bitmaps/south_korea.png.h"
#include "bitmaps/hungary.png.h"
#include "bitmaps/macedonia.png.h"
#include "bitmaps/netherlands.png.h"
#include "bitmaps/norway.png.h"
#include "bitmaps/poland.png.h"
#include "bitmaps/portugal.png.h"
#include "bitmaps/brazil.png.h"
#include "bitmaps/russia.png.h"
#include "bitmaps/slovakia.png.h"
#include "bitmaps/slovenia.png.h"
#include "bitmaps/serbia.png.h"
#include "bitmaps/sweden.png.h"
#include "bitmaps/ukraine.png.h"
#include "bitmaps/vietnam.png.h"

BitmapArray s_langBitmapArray;
const BitmapArray& GetLangBitmapArray() {
	if (s_langBitmapArray.size() == 0) {
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(armenia));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(china));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(china));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(czech));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(denmark));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(germany));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(united_kingdom));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(spain));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(basque_country));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(france));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(greece));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(italy));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(japan));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(south_korea));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(hungary));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(macedonia));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(netherlands));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(norway));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(poland));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(portugal));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(brazil));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(russia));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(slovakia));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(slovenia));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(serbia));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(sweden));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(ukraine));
		s_langBitmapArray.Add(wxBITMAP_FROM_MEMORY(vietnam));
	}
	return s_langBitmapArray;
};
